@@ -132,7 +132,7 @@ pub(crate) fn parse_l2(msg: &str) -> Result<Vec<OrderBookMsg>, SimpleError> {
         let parse_order = |raw_order: &[Value; 2]| -> Order {
             let price: f64 = if raw_order[0].is_string() {
                 raw_order[0].as_str().unwrap().parse::<f64>().unwrap()
-            } else if raw_order[0].is_f64() {
+            } else if raw_order[0].is_f64() || raw_order[0].is_i64() || raw_order[0].is_u64() {
                 raw_order[0].as_f64().unwrap()
             } else {
                 panic!("Unknown format {}", msg);
@@ -140,7 +140,7 @@ pub(crate) fn parse_l2(msg: &str) -> Result<Vec<OrderBookMsg>, SimpleError> {
 
             let quantity_base: f64 = if raw_order[1].is_string() {
                 raw_order[1].as_str().unwrap().parse::<f64>().unwrap()
-            } else if raw_order[1].is_f64() {
+            } else if raw_order[1].is_f64() || raw_order[1].is_i64() || raw_order[1].is_u64() {
                 raw_order[1].as_f64().unwrap()
             } else {
                 panic!("Unknown format {}", msg);
