@@ -154,15 +154,8 @@ pub(super) fn extract_timestamp(
     let channel = ws_msg[0].as_str().unwrap();
     match channel {
         "future_tick" => {
-            let raw_trades = ws_msg[1]["trades"].as_array().unwrap();
-            let timestamp = raw_trades.iter().fold(std::i64::MIN, |a, raw_trade| {
-                a.max(raw_trade[0].as_i64().expect(msg) / 1000)
-            });
-            if timestamp == std::i64::MIN {
-                Err(SimpleError::new(format!("result is empty in {}", msg)))
-            } else {
-                Ok(Some(timestamp))
-            }
+            let raw_trade = ws_msg[1]["trades"].as_array().unwrap();
+            Ok(Some(raw_trade[0].as_i64().unwrap() / 1000))
         }
         "future_snapshot_depth" => Ok(Some(ws_msg[1]["time"].as_i64().unwrap() / 1000)),
         _ => Err(SimpleError::new(format!(
